@@ -3,7 +3,7 @@ import json
 import sys
 
 
-def main(City State):
+def main():
 
     api_key = "f054a8afdf8d658df832afeccd66c806"
 
